@@ -247,9 +247,33 @@ run your application.
 
 =head1 STARTUP FILE
 
+Here is an example C<startup.pl> to preload PSGI applications:
+
+    #!/usr/bin/env perl
+
+    use strict;
+    use warnings;
+    use Apache2::ServerUtil ();
+
+    BEGIN {
+        return unless Apache2::ServerUtil::restart_count() > 1;
+
+        require lib;
+        lib->import('/path/to/my/perl/libs');
+
+        require Plack::Handler::Apache2;
+
+        my @psgis = ('/path/to/app1.psgi', '/path/to/app2.psgi');
+        foreach my $psgi (@psgis) {
+            Plack::Handler::Apache2->preload($psgi);
+        }
+    }
+
+    1; # file must return true!
+
 See L<http://perl.apache.org/docs/2.0/user/handlers/server.html#Startup_File>
-for information on the C<startup.pl> file for preloading perl modules and your
-apps.
+for general information on the C<startup.pl> file for preloading perl modules
+and your apps.
 
 Some things to keep in mind when writing this file:
 
@@ -262,7 +286,7 @@ otherwise your app will load twice and the env vars you set with
 L<PerlSetEnv|http://perl.apache.org/docs/2.0/user/config/config.html#C_PerlSetEnv_>
 will not be available when your app is loading the first time.
 
-Use the example below as a template.
+Use the example above as a template.
 
 =item * C<@INC>
 
@@ -271,7 +295,7 @@ Use L<lib> to add entries, they can be in your app or C<.psgi> as well, but if
 your modules are in a L<local::lib> or some such, you will need to add the path
 for anything to load.
 
-Alternately, if you follow the example below, you can use:
+Alternately, if you follow the example above, you can use:
 
     PerlSetEnv PERL5LIB /some/path
 
@@ -335,30 +359,6 @@ accomplish this:
 
 =back
 
-Here is an example C<startup.pl>:
-
-    #!/usr/bin/env perl
-
-    use strict;
-    use warnings;
-    use Apache2::ServerUtil ();
-
-    BEGIN {
-        return unless Apache2::ServerUtil::restart_count() > 1;
-
-        require lib;
-        lib->import('/path/to/my/perl/libs');
-
-        require Plack::Handler::Apache2;
-
-        my @psgis = ('/path/to/app1.psgi', '/path/to/app2.psgi');
-        foreach my $psgi (@psgis) {
-            Plack::Handler::Apache2->preload($psgi);
-        }
-    }
-
-    1; # file must return true!
-
 =head1 AUTHOR
 
 Tatsuhiko Miyagawa
